pages = [
    "Home" => "index.md",
    "tutorials/getting_started.md",
    "Tutorials" => Any[
        "Demonstration of Operator Algebras and Kron" => "tutorials/operator_algebras.md",
        "FFT Tutorial" => "tutorials/fftw.md",
    ],
    "interface.md",
    "Premade Operators" => "premade_operators.md",
]
